
import javax.microedition.lcdui.game.Sprite;

/**
 * Entre 2 Almas	[https://sourceforge.net/projects/entre2almas/]  
 * ------------------------------------------------------------------------
 * This file is part of "Entre 2 Almas".
 * "Entre 2 Almas" is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.

 * "Entre 2 Almas" is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with "Entre 2 Almas"; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * ------------------------------------------------------------------------
 * 		Copyright 2005 - 2006 Pedro Javier Sez Martnez
 * 
 * 
 * Un objeto Estancia, puede estar formado de objetos Escenario. Implementa la
 * interfaz Comparable
 * 
 * @author Pedro Javier Sez Martnez
 * @version 1.0
 */
public class Escenario implements Comparable {

	/**
	 * Identificador del escenario
	 */
	int id;

	/**
	 * Nombre del escenario.
	 */
	String nombre;

	/**
	 * Posicin inicial X, en la que empieza el personaje principal en el
	 * escenario
	 */
	int posInicialX;

	/**
	 * Posicin inicial Y, en la que empieza el personaje principal en el
	 * escenario
	 */
	int posInicialY;

	/**
	 * Imagen que representar al Escenario. La imagen de cada escenario estar
	 * formado por 3 frames, el 1 ser la representacin del escenario que se
	 * ver por pantalla (delante del personaje), el 2 es el escenario que se
	 * ve por detrs del personaje y el 3 es el rea caminable del escenario
	 */
	public Sprite representa;

	/**
	 * Indices de, entre las imgenes que forman el sprite representa, las
	 * imgenes que corresponden a la parte de atrs, a la de delante y a la
	 * caminable.
	 */
	int imDelante;

	int imDetras;

	int imCaminable;

	/**
	 * Indica si un escenario, tiene alguna parte del escenario, la cual est
	 * por delante del personaje En caso de que est a true, el escenario tendr
	 * 3 frames: - 1 para lo que se ve delante - 2 para lo que se ve detrs -
	 * 3 el rea caminable En caso contrario solo tendr 2: - 1 la parte del
	 * escenario que se ve detrs. - 2 el rea caminable.
	 */
	boolean delante;

	/**
	 * Items que va a haber en el escenario
	 */
	AVLTree items;

	/**
	 * Constructor de Escenario
	 * 
	 * @param id
	 *            Identificador del Escenario
	 * @param nombre
	 *            Nombre del escenario
	 * @param imagen
	 *            identificador de Utils que define la imagen que representa
	 *            este escenario
	 * @param posInicialX
	 *            Posicin inicial X, en la que empieza el personaje principal
	 *            en el escenario
	 * @param posInicialY
	 *            Posicin inicial Y, en la que empieza el personaje principal
	 *            en el escenario
	 * @param items
	 *            Items que va a haber en el escenario
	 * @param delante
	 *            Indica si un escenario, tiene alguna parte del escenario, la
	 *            cual est por delante del personaje
	 */
	public Escenario(int id, String nombre, String imagen, int posInicialX,
			int posInicialY, AVLTree items, boolean delante) {
		this.id = id;
		this.nombre = nombre;
		//		cargamos la representacin del escenario
		Utils.cargarImagen(imagen);
		representa = new Sprite(Utils.imagen, Utils.anchoIm, Utils.altoIm);
		representa.setFrameSequence(Utils.getFrames(imagen));
		representa.setPosition(Utils.inicioPantallaX, Utils.inicioPantallaY);

		this.posInicialX = posInicialX;
		this.posInicialY = posInicialY;

		this.items = items;

		this.delante = delante;
		if (delante) {
			imDelante = 0;
			imDetras = 1;
			imCaminable = 2;
		} else {
			imDelante = -1;
			imDetras = 0;
			imCaminable = 1;
		}
	}

	/**
	 * @return Devuelve el posInicialX.
	 */
	public int getPosInicialX() {
		if (Utils.grupo == 1)//si es de 176x200
			return (posInicialX * Utils.aumentaX) / 1000;
		return posInicialX;
	}

	/**
	 * @return Devuelve el posInicialY.
	 */
	public int getPosInicialY() {
		if (Utils.grupo == 1)//si es de 176x200
			return (posInicialY * Utils.aumentaY) / 1000;
		return posInicialY;
	}

	/**
	 * Devuelve la clave del comparable
	 * 
	 * @return La clave del comparable identificador del comparable.
	 */
	public int getKey() {
		return id;
	}
}
